@@ -18,38 +18,41 @@ from pathlib import Path
 from typing import Optional
 
 from robot.utils import get_link_path  # type: ignore
-from robotlibcore import keyword  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import keyword, logger
 
 
 class Control(LibraryComponent):
     """Keywords to do things on the current browser page and modify the page"""
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def go_forward(self):
         """Navigates to the next page in history."""
         with self.playwright.grpc_channel() as stub:
             response = stub.GoForward(Request.Empty())
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def go_back(self):
         """Navigates to the previous page in history."""
         with self.playwright.grpc_channel() as stub:
             response = stub.GoBack(Request.Empty())
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "BrowserControl"])
-    def go_to(self, url: str):
+    @keyword(tags=("Setter", "BrowserControl"))
+    def go_to(self, url: str, timeout: Optional[timedelta] = None):
         """Navigates to the given ``url``.
 
-        ``url`` <str> URL to be navigated to. **Required**
+        ``url`` <str> URL to be navigated to.
+        ``timeout`` <str> time to wait page to load. If not defined
+        will use the the library default timeout.
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.GoTo(Request().Url(url=url))
+            response = stub.GoTo(
+                Request().Url(url=url, defaultTimeout=int(self.get_timeout(timeout)))
+            )
             logger.info(response.log)
 
     def _get_screenshot_path(self, filename: str) -> Path:
@@ -67,7 +70,7 @@ class Control(LibraryComponent):
             if not path.with_suffix(".png").is_file():
                 return path
 
-    @keyword(tags=["PageContent"])
+    @keyword(tags=("PageContent",))
     def take_screenshot(
         self,
         filename: str = "robotframework-browser-screenshot-{index}",
@@ -76,17 +79,17 @@ class Control(LibraryComponent):
     ) -> str:
         """Takes a screenshot of the current window and saves it to ``path``. Saves it as a png.
 
-        ``filename`` <str> Filename into which to save. The file will be saved into the robot framework output
+        ``filename`` Filename into which to save. The file will be saved into the robot framework output
         directory by default. String ``{index}`` in path will be replaced with a rolling number. Use this to not
         override filenames. If filename equals to EMBED (case insensitive), then screenshot is embedded as
         Base64 image to the log.html. The image is saved temporally to the disk and warning is displayed
         if removing the temporary file fails.
 
-        ``selector`` <str> Take a screenshot of the element matched by selector.
+        ``selector`` Take a screenshot of the element matched by selector.
         See the `Finding elements` section for details about the selectors.
         If not provided take a screenshot of current viewport.
 
-        ``fullPage`` <bool> When True, takes a screenshot of the full scrollable page,
+        ``fullPage`` When True, takes a screenshot of the full scrollable page,
         instead of the currently visible viewport. Defaults to False.
         """
         if self._is_embed(filename):
@@ -99,7 +102,7 @@ class Control(LibraryComponent):
         return self._log_image_link(file_path)
 
     def _log_image_link(self, file_path: str) -> str:
-        relative_path = get_link_path(file_path, self.library.outputdir)
+        relative_path = get_link_path(file_path, self.outputdir)
         logger.info(
             '</td></tr><tr><td colspan="3">'
             f'<a href="{relative_path}"><img src="{relative_path}" width="800px"></a>',
@@ -139,11 +142,11 @@ class Control(LibraryComponent):
     def _is_embed(self, filename: str) -> bool:
         return True if filename.upper() == "EMBED" else False
 
-    @keyword(tags=["Setter", "Config"])
+    @keyword(tags=("Setter", "Config"))
     def set_browser_timeout(self, timeout: timedelta) -> str:
         """Sets the timeout used by most input and getter keywords.
 
-        ``timeout`` <str> Timeout of it is for current playwright context. **Required**
+        ``timeout`` Timeout of it is for current playwright context.
 
         Returns the previous value of the timeout.
         """
@@ -154,11 +157,11 @@ class Control(LibraryComponent):
             logger.info(response.log)
         return old_timeout
 
-    @keyword(tags=["Setter", "Config"])
+    @keyword(tags=("Setter", "Config"))
     def set_retry_assertions_for(self, timeout: timedelta) -> str:
         """Sets the timeout used in retrying assertions when they fail.
 
-        ``timeout`` <str>
+        ``timeout``
 
         Returns the previous value of the retry_assertions_until.
         """
@@ -166,7 +169,7 @@ class Control(LibraryComponent):
         self.retry_assertions_for = self.convert_timeout(timeout)
         return old_retry_assertions_for
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def set_viewport_size(self, width: int, height: int):
         """Sets current Pages viewport size to specified dimensions.
 
@@ -180,9 +183,9 @@ class Control(LibraryComponent):
         so you should set the viewport size before navigating to
         the page with `New Context` before opening the page itself.
 
-        ``width`` <int> Sets the width size. **Required**
+        ``width`` Sets the width size.
 
-        ``height`` <int> Sets the heigth size. **Required**
+        ``height`` Sets the heigth size.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.SetViewportSize(
@@ -190,18 +193,18 @@ class Control(LibraryComponent):
             )
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def set_offline(self, offline: bool = True):
         """Toggles current Context's offline emulation.
 
-        ``offline`` <bool> Toggles the offline mode. Set to False to switch back
+        ``offline`` Toggles the offline mode. Set to False to switch back
         to online mode. Defaults to True.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.SetOffline(Request().Bool(value=offline))
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def set_geolocation(
         self, latitude: float, longitude: float, accuracy: Optional[float] = None
     ):
@@ -218,7 +221,7 @@ class Control(LibraryComponent):
             response = stub.SetGeolocation(Request().Json(body=geolocation))
             logger.info(response.log)
 
-    @keyword(tags=["Setter", "BrowserControl"])
+    @keyword(tags=("Setter", "BrowserControl"))
     def reload(self):
         """Reloads current active page."""
         with self.playwright.grpc_channel() as stub:
