@@ -15,8 +15,6 @@
 import json
 from typing import Any, List, Optional, Union
 
-from robotlibcore import keyword  # type: ignore
-
 from ..assertion_engine import (
     bool_verify_assertion,
     dict_verify_assertion,
@@ -28,18 +26,19 @@ from ..assertion_engine import (
 )
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import exec_scroll_function, logger
+from ..utils import exec_scroll_function, keyword, logger
 from ..utils.data_types import (
     AreaFields,
     AssertionOperator,
     BoundingBoxFields,
+    ElementStateKey,
     SelectAttribute,
     SizeFields,
 )
 
 
 class Getters(LibraryComponent):
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_url(
         self,
@@ -60,7 +59,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, "URL "
             )
 
-    # @keyword(tags=["Getter", "Assertion", "BrowserControl"])
+    # @keyword(tags=("Getter", "Assertion", "BrowserControl"))
     # Not published as keyword due to missing of good docs.
     @with_assertion_polling
     def get_page_state(
@@ -88,7 +87,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, "State "
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_page_source(
         self,
@@ -109,7 +108,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, "HTML: "
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_title(
         self,
@@ -130,7 +129,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, "Title "
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     def get_text(
         self,
         selector: str,
@@ -148,7 +147,7 @@ class Getters(LibraryComponent):
             selector, "innerText", assertion_operator, assertion_expected
         )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_property(
         self,
@@ -162,10 +161,10 @@ class Getters(LibraryComponent):
         Optionally asserts that the property value matches the specified
         assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``property`` <str> Requested property name. **Required**
+        ``property`` Requested property name.
 
         If ``assertion_operator`` is set and property is not found, ``value`` is ``None``
         and Keyword does not fail. See `Get Attribute` for examples.
@@ -187,7 +186,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, f"Property {property}"
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_attribute(
         self,
@@ -201,10 +200,10 @@ class Getters(LibraryComponent):
         Optionally asserts that the attribute value matches the specified
         assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``attribute`` <str> Requested attribute name. **Required**
+        ``attribute`` Requested attribute name.
 
         When a attribute is selected that is not present and no assertion operator is set,
         the keyword fails. If an assertion operator is set and the attribute is not present,
@@ -236,7 +235,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, f"Attribute {selector}"
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_attribute_names(
         self,
@@ -248,10 +247,10 @@ class Getters(LibraryComponent):
 
         Optionally asserts that these match the specified assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
 
         Available assertions:
         - ``==`` and ``!=`` can work with multiple values
@@ -267,7 +266,7 @@ class Getters(LibraryComponent):
             attribute_names, assertion_operator, expected, "Attribute names"
         )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_classes(
         self,
@@ -279,10 +278,10 @@ class Getters(LibraryComponent):
 
         Optionally asserts that the value matches the specified assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
 
         Available assertions:
         - ``==`` and ``!=`` can work with multiple values
@@ -299,7 +298,7 @@ class Getters(LibraryComponent):
             f"Classes of {selector}",
         )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_textfield_value(
         self,
@@ -311,7 +310,7 @@ class Getters(LibraryComponent):
 
         Optionally asserts that the value matches the specified assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
         See `Assertions` for further details for the assertion arguments. Defaults to None.
@@ -323,7 +322,7 @@ class Getters(LibraryComponent):
             f"Value {selector}",
         )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_selected_options(
         self,
@@ -336,13 +335,13 @@ class Getters(LibraryComponent):
 
         Optionally asserts that these match the specified assertion.
 
-        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        ``selector`` Selector from which the info is to be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``option_attribute`` <SelectAttribute.label> Which attribute shall be returned/verified.
-        Allowed values are ``< ``value`` | ``label`` | ``text`` | ``index`` >``. Defaults to label.
+        ``option_attribute`` Which attribute shall be returned/verified.
+        Defaults to label.
 
-        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
 
         - ``==`` and ``!=`` can work with multiple values
         - ``contains``/``*=`` only accepts one single expected value
@@ -384,7 +383,7 @@ class Getters(LibraryComponent):
                 "Selected Options:",
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_checkbox_state(
         self,
@@ -394,17 +393,17 @@ class Getters(LibraryComponent):
     ) -> bool:
         """Returns the state of the checkbox found by ``selector``.
 
-        ``selector`` <str> Selector which shall be examined.
+        ``selector`` Selector which shall be examined.
         See the `Finding elements` section for details about the selectors.
 
         Optionally asserts that the state matches the specified assertion.
 
-        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
 
         - ``==`` and ``!=`` and equivalent are allowed on boolean values
         - other operators are not accepted.
 
-        ``expected_state`` <str> boolean value of expected state.
+        ``expected_state`` boolean value of expected state.
         Strings are interpreted as booleans.
         All strings are ``${True}`` except of the
         following `FALSE, NO, OFF, 0, UNCHECKED, NONE, ${EMPTY}``.
@@ -425,7 +424,7 @@ class Getters(LibraryComponent):
                 value, assertion_operator, expected_state, f"Checkbox {selector} is"
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_element_count(
         self,
@@ -437,12 +436,12 @@ class Getters(LibraryComponent):
 
         Optionally asserts that the count matches the specified assertion.
 
-        ``selector`` <str> Selector which shall be counted.
+        ``selector`` Selector which shall be counted.
         See the `Finding elements` section for details about the selectors.
 
-        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
 
-        ``expected_value`` <str|int> Expected value for the counting
+        ``expected_value`` Expected value for the counting
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElementCount(
@@ -456,7 +455,7 @@ class Getters(LibraryComponent):
                 f"Element count for selector `{selector}` is",
             )
 
-    @keyword(tags=["Getter", "Assertion", "BrowserControl"])
+    @keyword(tags=("Getter", "Assertion", "BrowserControl"))
     @with_assertion_polling
     def get_viewport_size(
         self,
@@ -468,7 +467,7 @@ class Getters(LibraryComponent):
 
         Optionally asserts that the count matches the specified assertion.
 
-        ``key`` < ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        ``key`` Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the viewport size as dictionary,
         otherwise it will just return the single value selected by the key.
         Note: If a single value is retrieved, an assertion does *not* need a ``validate``
@@ -499,24 +498,24 @@ class Getters(LibraryComponent):
                     f"{key} is ",
                 )
 
-    @keyword(tags=["Getter", "PageContent"])
+    @keyword(tags=("Getter", "PageContent"))
     def get_element(self, selector: str) -> str:
         """Returns a reference to a Playwright element handle.
 
         The reference can be used in subsequent selectors.
 
-        ``selector`` <str> Selector from which shall be retrieved **Required**.
+        ``selector`` Selector from which shall be retrieved .
         See the `Finding elements` section for details about the selectors.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElement(Request().ElementSelector(selector=selector))
             return response.body
 
-    @keyword(tags=["Getter", "PageContent"])
+    @keyword(tags=("Getter", "PageContent"))
     def get_elements(self, selector: str) -> List[str]:
         """Returns a reference to playwright element handle for all matched elements by ``selector``.
 
-        ``selector`` <str> Selector from which shall be retrieved. **Required**
+        ``selector`` Selector from which shall be retrieved.
         See the `Finding elements` section for details about the selectors.
         """
         try:
@@ -526,11 +525,11 @@ class Getters(LibraryComponent):
                 )
                 return json.loads(response.json)
         except AssertionError as error:
-            if "Could not find element with" in str(error):
+            if "page.waitForSelector: Timeout" in str(error):
                 return []
             raise error
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     @with_assertion_polling
     def get_style(
         self,
@@ -543,10 +542,10 @@ class Getters(LibraryComponent):
 
         Optionally matches with any sequence assertion operator.
 
-        ``selector`` <str> Selector from which the style shall be retrieved. **Required**
+        ``selector`` Selector from which the style shall be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``key`` <str> Key of the requested CSS property. Retrieves "ALL" styles by default.
+        ``key`` Key of the requested CSS property. Retrieves "ALL" styles by default.
 
         See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
@@ -569,7 +568,7 @@ class Getters(LibraryComponent):
                     f"Style value for {key} is ",
                 )
 
-    @keyword(name="Get BoundingBox", tags=["Getter", "Assertion", "PageContent"])
+    @keyword(name="Get BoundingBox", tags=("Getter", "Assertion", "PageContent"))
     def get_boundingbox(
         self,
         selector: str,
@@ -579,10 +578,10 @@ class Getters(LibraryComponent):
     ) -> Any:
         """Gets elements size and location as an object ``{x: float, y: float, width: float, height: float}``.
 
-        ``selector`` <str> Selector from which shall be retrieved. **Required**
+        ``selector`` Selector from which shall be retrieved.
         See the `Finding elements` section for details about the selectors.
 
-        ``key`` < ``x`` | ``y`` | ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        ``key`` Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the BoundingBox as Dictionary,
         otherwise it will just return the single value selected by the key.
         Note: If a single value is retrieved, an assertion does *not* need a ``validate``
@@ -602,7 +601,7 @@ class Getters(LibraryComponent):
         with self.playwright.grpc_channel() as stub:
             response = stub.GetBoundingBox(Request.ElementSelector(selector=selector))
             parsed = json.loads(response.json)
-            logger.debug(parsed)
+            logger.debug(f"BoundingBox: {parsed}")
             if key == BoundingBoxFields.ALL:
                 return int_dict_verify_assertion(
                     parsed, assertion_operator, assertion_expected, "BoundingBox is"
@@ -616,7 +615,7 @@ class Getters(LibraryComponent):
                     f"BoundingBox {key.name} is ",
                 )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     def get_scroll_size(
         self,
         selector: Optional[str] = None,
@@ -626,11 +625,11 @@ class Getters(LibraryComponent):
     ) -> Any:
         """Gets elements or pages scrollable size as object ``{width: float, height: float}``.
 
-        ``selector`` <str> Optional selector from which shall be retrieved.
+        ``selector`` Optional selector from which shall be retrieved.
         If no selector is given the scroll size of the page itself is used.
         See the `Finding elements` section for details about the selectors.
 
-        ``key`` < ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        ``key`` Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the scroll size as dictionary,
         otherwise it will just return the single value selected by the key.
 
@@ -663,7 +662,7 @@ class Getters(LibraryComponent):
                 f"Scroll {key.name} is ",
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     def get_scroll_position(
         self,
         selector: Optional[str] = None,
@@ -679,11 +678,11 @@ class Getters(LibraryComponent):
         ``top`` uses js function scrollTop, ``left`` uses scrollLeft and
         ``bottom`` and ``right`` are calculated with the client size.
 
-        ``selector`` <str> Optional selector from which shall be retrieved.
+        ``selector`` Optional selector from which shall be retrieved.
         If no selector is given the client size of the page itself is used (``document.scrollingElement``).
         See the `Finding elements` section for details about the selectors.
 
-        ``key`` < ``top`` | ``left`` | ``bottom`` | ``right`` | ``ALL`` > Optionally filters the returned values.
+        ``key`` Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the scroll position as dictionary,
         otherwise it will just return the single value selected by the key.
 
@@ -713,7 +712,7 @@ class Getters(LibraryComponent):
                 f"Scroll position {key.name} is ",
             )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
     def get_client_size(
         self,
         selector: Optional[str] = None,
@@ -723,11 +722,11 @@ class Getters(LibraryComponent):
     ) -> Any:
         """Gets elements or pages client size (``clientHeight``, ``clientWidth``) as object {width: float, height: float}.
 
-        ``selector`` <str> Optional selector from which shall be retrieved.
+        ``selector`` Optional selector from which shall be retrieved.
         If no selector is given the client size of the page itself is used (``document.scrollingElement``).
         See the `Finding elements` section for details about the selectors.
 
-        ``key`` < ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        ``key`` Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the scroll size as dictionary,
         otherwise it will just return the single value selected by the key.
 
@@ -753,3 +752,71 @@ class Getters(LibraryComponent):
                 assertion_expected,
                 f"Client {key.name} is ",
             )
+
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
+    def get_element_state(
+        self,
+        selector: str,
+        state: ElementStateKey = ElementStateKey.visible,
+        assertion_operator: Optional[AssertionOperator] = None,
+        assertion_expected: bool = True,
+    ):
+        """Get the given state from the element found by ``selector``.
+
+        If the selector does satisfy the expected state it will return ``True`` otherwise ``False``.
+
+        ``selector`` Selector of the corresponding object.
+        See the `Finding elements` section for details about the selectors.
+
+        ``state`` Defaults to visible. Possible states are:
+        - ``attached``: to be present in DOM.
+        - ``visible``: to have non-empty bounding box and no visibility:hidden.
+        - ``disabled``: to be ``disabled``. Can be used on <button>, <fieldset>, <input>, <optgroup>, <option>, <select> and <textarea>.
+        - ``readonly``: to be ``readOnly``. Can be used on <input> and <textarea>.
+        - ``selected``: to be ``selected``. Can be used on <option>.
+        - ``focused``: to be the ``activeElement``.
+        - ``checked``: to be ``checked``. Can be used on <input>.
+
+        Note that element must be attached to DOM to be able to fetch the state of ``readonly``, ``selectec`` and ``checked``.
+        The other states are false if the requested element is not attached.
+
+        Note that element without any content or with display:none has an empty bounding box
+        and is not considered visible.
+        """
+        funct = {
+            ElementStateKey.disabled: "e => e.disabled",
+            ElementStateKey.readonly: "e => e.readOnly",
+            ElementStateKey.selected: "e => e.selected",
+            ElementStateKey.focused: "e => document.activeElement === e",
+            ElementStateKey.checked: "e => e.checked",
+        }
+
+        with self.playwright.grpc_channel() as stub:
+            try:
+                if state in funct:
+                    stub.WaitForFunction(
+                        Request().WaitForFunctionOptions(
+                            script=funct[state],
+                            selector=selector,
+                            options=json.dumps({"timeout": 100}),
+                        )
+                    )
+                else:
+                    stub.WaitForElementsState(
+                        Request().ElementSelectorWithOptions(
+                            selector=selector,
+                            options=json.dumps({"state": state.name, "timeout": 100}),
+                        )
+                    )
+                result = True
+            except Exception as e:
+                if "Timeout 100ms exceeded." in e.args[0].details:
+                    result = False
+                else:
+                    raise e
+            return bool_verify_assertion(
+                result,
+                assertion_operator,
+                assertion_expected,
+                f"State '{state.name}' of '{selector}' is",
+            )
