@@ -13,18 +13,21 @@
 # limitations under the License.
 
 import json
+import os
 from datetime import timedelta
 from pathlib import Path
+from time import sleep
 from typing import Any, Dict, Optional
 
-from robotlibcore import keyword  # type: ignore
-
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
 from ..utils import (
     exec_scroll_function,
     get_abs_scroll_coordinates,
     get_rel_scroll_coordinates,
+    get_variable_value,
+    keyword,
+    locals_to_params,
     logger,
 )
 from ..utils.data_types import (
@@ -41,9 +44,11 @@ from ..utils.data_types import (
     SelectAttribute,
 )
 
+NOT_FOUND = object()
+
 
 class Interaction(LibraryComponent):
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def type_text(
         self,
         selector: str,
@@ -56,24 +61,25 @@ class Interaction(LibraryComponent):
         Sends a ``keydown``, ``keypress/input``, and ``keyup`` event for each
         character in the text.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
-        ``text`` <str> Text for the text field. **Required**
+        ``text`` Text for the text field.
 
-        ``delay`` <str> Delay between the single key strokes. It may be either a
+        ``delay`` Delay between the single key strokes. It may be either a
         number or a Robot Framework time string. Time strings are fully
         explained in an appendix of Robot Framework User Guide. Defaults to ``0 ms``.
         Example: ``50 ms``
 
-        ``clear`` <bool> Set to false, if the field shall not be cleared before typing.
+        ``clear`` Set to false, if the field shall not be cleared before typing.
         Defaults to true.
 
         See `Fill Text` for direct filling of the full text at once.
         """
+        logger.info(f"Types the text '{text}' in the given field.")
         self._type_text(selector, text, delay, clear)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def fill_text(self, selector: str, text: str):
         """Clears and fills the given ``text`` into the text field found by ``selector``.
 
@@ -85,20 +91,21 @@ class Interaction(LibraryComponent):
         [contenteditable] element, this method throws an error. Note that
         you can pass an empty string as ``text`` to clear the input field.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
-        ``text`` <str> Text for the text field. **Required**
+        ``text`` Text for the text field.
 
         See `Type Text` for emulating typing text character by character.
         """
+        logger.info(f"Fills the text '{text}' in the given field.")
         self._fill_text(selector, text)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def clear_text(self, selector: str):
         """Clears the text field found by ``selector``.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
         See `Type Text` for emulating typing text character by character.
@@ -109,7 +116,7 @@ class Interaction(LibraryComponent):
             response = stub.ClearText(Request().ClearText(selector=selector))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def type_secret(
         self,
         selector: str,
@@ -117,49 +124,109 @@ class Interaction(LibraryComponent):
         delay: timedelta = timedelta(seconds=0),
         clear: bool = True,
     ):
-        """Types the given ``secret`` into the text field found by ``selector``.
+        """Types the given secret from ``variable_name`` into the text field
+        found by ``selector``.
 
-        The difference to `Type Text` is that this keyword does not log the
-        text to be written into the text field.
+        This keyword does not log secret in Robot Framework logs.
+        If ``enable_playwright_debug`` is enabled in the library
+        import, secret will be always visible as plain text in the playwright debug
+        logs, regardless of the Robot Framework log level.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
-        ``secret`` <str> Secret text for the text field. **Required**
+        ``secret`` Environment variable name with % prefix or a local
+        variable with $ prefix that has the secret text value.
+        Variable names can be used with and without curly braces.
 
-        ``delay`` <str> Delay between the single key strokes. It may be either a
+        Example:
+        ``$Password`` and ``${Password}`` resolve the robot framework variable.
+        ``%ENV_PWD`` and ``%{ENV_PWD}`` resolve to the environment variable ``ENV_PWD``.
+
+        ``delay`` Delay between the single key strokes. It may be either a
         number or a Robot Framework time string. Time strings are fully
         explained in an appendix of Robot Framework User Guide. Defaults to ``0 ms``.
         Example: ``50 ms``
 
-        ``clear`` <bool> Set to false, if the field shall not be cleared before typing.
+        ``clear`` Set to false, if the field shall not be cleared before typing.
         Defaults to true.
 
         See `Type Text` for details.
         """
+        originals = self._get_original_values(locals())
+        secret = self._resolve_secret(secret, originals.get("secret") or secret)
         self._type_text(selector, secret, delay, clear, log_response=False)
 
-    @keyword(tags=["Setter", "PageContent"])
+    def _get_original_values(self, local_args: Dict[str, Any]) -> Dict[str, Any]:
+        originals = locals_to_params(local_args)
+        if not self.library.current_arguments:
+            return originals
+        named_args = False
+        for idx, val in enumerate(self.library.current_arguments):
+            if idx > len(originals):
+                break
+            if "=" in val and not named_args:
+                named_args = val.split("=", 1)[0] in originals
+            if named_args:
+                arg_name, arg_value = val.split("=", 1)
+                originals[arg_name] = arg_value
+            else:
+                originals[list(originals.keys())[idx]] = val
+        return originals
+
+    @keyword(tags=("Setter", "PageContent"))
     def fill_secret(self, selector: str, secret: str):
-        """Fills the given ``secret`` into the text field found by ``selector``.
+        """Fills the given secret from ``variable_name`` into the
+        text field found by ``selector``.
 
-        The difference to `Fill Text` is that this keyword does not log the
-        text to be written into the text field.
+        This keyword does not log secret in Robot Framework logs.
+        If ``enable_playwright_debug`` is enabled in the library
+        import, secret will be always visible as plain text in the playwright debug
+        logs, regardless of the Robot Framework log level.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
-        ``secret`` <str> Secret text for the text field. **Required**
+        ``secret`` Environment variable name with % prefix or a local
+        variable with $ prefix that has the secret text value.
+        Variable names can be used with and without curly braces.
 
-        See `Fill Text` for details.
+        Example:
+        ``$Password`` and ``${Password}`` resolve the robot framework variable.
+        ``%ENV_PWD`` and ``%{ENV_PWD}`` resolve to the environment variable ``ENV_PWD``.
+
+        See `Fill Text` for other details.
         """
+        originals = self._get_original_values(locals())
+        secret = self._resolve_secret(secret, originals.get("secret") or secret)
         self._fill_text(selector, secret, log_response=False)
 
-    @keyword(tags=["Setter", "PageContent"])
+    def _resolve_secret(self, secret_variable: str, original_secret) -> str:
+        secret = self._replace_placeholder_variables(secret_variable)
+        if secret == original_secret:
+            logger.warn(
+                "Direct assignment of values as 'secret' is deprecated."
+                "Use variables or environment variables instead."
+            )
+        return secret
+
+    def _replace_placeholder_variables(self, placeholder):
+        if not isinstance(placeholder, str) or placeholder[:1] not in "$%":
+            return placeholder
+        if placeholder.startswith("%"):
+            value = os.environ.get(placeholder[1:], NOT_FOUND)
+        else:
+            value = get_variable_value(placeholder, NOT_FOUND)
+        if value is NOT_FOUND:
+            logger.warn("Given variable placeholder could not be resolved.")
+            return placeholder
+        return value
+
+    @keyword(tags=("Setter", "PageContent"))
     def press_keys(self, selector: str, *keys: str):
         """Types the given key combination into element found by ``selector``.
 
-        ``selector`` <str> Selector of the text field. **Required**
+        ``selector`` Selector of the text field.
         See the `Finding elements` section for details about the selectors.
 
         Supports values like "a, b" which will be automatically typed.
@@ -181,33 +248,7 @@ class Interaction(LibraryComponent):
             response = stub.Press(Request().PressKeys(selector=selector, key=keys))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
-    def click_with_options(
-        self,
-        selector: str,
-        button: MouseButton = MouseButton.left,
-        clickCount: int = 1,
-        delay: Optional[timedelta] = None,
-        position_x: Optional[float] = None,
-        position_y: Optional[float] = None,
-        force: bool = False,
-        noWaitAfter: bool = False,
-        *modifiers: KeyboardModifier,
-    ):
-        """*DEPRECATED* Use `Click` instead."""
-        self.click(
-            selector,
-            button,
-            clickCount,
-            delay,
-            position_x,
-            position_y,
-            force,
-            noWaitAfter,
-            *modifiers,
-        )
-
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def click(
         self,
         selector: str,
@@ -229,29 +270,29 @@ class Interaction(LibraryComponent):
         - Use `Mouse Button` to click in the center of the element, or the specified position.
         - Wait for initiated navigation to either succeed or fail, unless ``noWaitAfter`` option is set.
 
-        ``selector`` <str> Selector element to click. **Required**
+        ``selector`` Selector element to click.
         See the `Finding elements` section for details about the selectors.
 
-        ``button`` < ``left`` | ``right`` | ``middle`` > Defaults to ``left`` if invalid.
+        ``button`` Defaults to ``left`` if invalid.
 
-        ``click_count`` <int> Defaults to 1.
+        ``click_count`` Defaults to 1.
 
-        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up.
+        ``delay`` Time to wait between mouse-down and mouse-up.
         Defaults to 0.
 
-        ``position_x`` & ``position_y`` <float> A point to click relative to the
+        ``position_x`` & ``position_y`` A point to click relative to the
         top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
         If not specified, clicks to some visible point of the element.
 
-        ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
+        ``force`` Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
 
-        ``noWaitAfter`` <bool> Actions that initiate navigation, are waiting for
+        ``noWaitAfter`` Actions that initiate navigation, are waiting for
         these navigation to happen and for pages to start loading.
         You can opt out of waiting via setting this flag.
         You would only need this option in the exceptional cases such as navigating
         to inaccessible pages. Defaults to ``False``.
 
-        ``*modifiers`` < ``Alt`` | ``Control`` | ``Meta`` | ``Shift`` >
+        ``*modifiers``
         Modifier keys to press. Ensures that only these modifiers are pressed
         during the click, and then restores current modifiers back.
         If not specified, currently pressed modifiers are used.
@@ -280,7 +321,7 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def hover(
         self,
         selector: str,
@@ -297,28 +338,17 @@ class Interaction(LibraryComponent):
         - Scroll the element into view if needed.
         - Use `Mouse Move` to hover over the center of the element, or the specified ``position``.
 
-        ``selector`` <str> Selector element to click. **Required**
+        ``selector`` Selector element to hover.
         See the `Finding elements` section for details about the selectors.
 
-        ``button`` < ``left`` | ``middle`` |  ``right``> The button that shall be used for clicking.
+        ``position_x`` & ``position_y`` A point to hover relative to the top-left corner of element bounding box.
+        If not specified, hovers over some visible point of the element.
+        Only positive values within the bounding-box are allowed.
 
-        ``clickCount`` <int> How many time shall be clicked.
+        ``force`` Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
 
-        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up and next click.
-
-        *Caution: be aware that if the delay leads to a total time that exceeds the timeout, the keyword fails*
-
-        ``position_x`` & ``position_y`` <float> A point to click relative to the
-        top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
-        If not specified, clicks to some visible point of the element.
-
-        *Caution: even with 0, 0 might click a few pixels off from the corner of the bounding-box. Click uses detection to find the first clickable point.*
-
-        ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
-
-        ``*modifiers`` < ``Alt`` | ``Control`` | ``Meta`` | ``Shift`` >
-        Modifier keys to press. Ensures that only these modifiers are pressed
-        during the click, and then restores current modifiers back.
+        ``*modifiers`` Modifier keys to press. Ensures that only these modifiers are
+        pressed during the hover, and then restores current modifiers back.
         If not specified, currently pressed modifiers are used.
         """
         with self.playwright.grpc_channel() as stub:
@@ -337,11 +367,11 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def focus(self, selector: str):
         """Moves focus on to the element found by ``selector``.
 
-        ``selector`` <str> Selector of the element. **Required**
+        ``selector`` Selector of the element.
         See the `Finding elements` section for details about the selectors.
 
         If there's no element matching selector, the method waits until a
@@ -351,7 +381,7 @@ class Interaction(LibraryComponent):
             response = stub.Focus(Request().ElementSelector(selector=selector))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def scroll_to(
         self,
         selector: Optional[str] = None,
@@ -361,22 +391,21 @@ class Interaction(LibraryComponent):
     ):
         """Scrolls an element or the page to an absolute position based on given coordinates.
 
-        ``selector`` <str> Selector of the element. If the selector is ``${None}`` or ``${Empty}``
+        ``selector`` Selector of the element. If the selector is ``${None}`` or ``${Empty}``
         the page itself is scrolled.
         See the `Finding elements` section for details about the selectors.
 
-        ``vertical`` <str> defines where to scroll vertically.
+        ``vertical`` defines where to scroll vertically.
         It can be a positive number, like ``300``.
         It can be a percentage value of the absolute scrollable size, like ``50%``.
         It can be a string defining that top or the bottom of the scroll area. < ``top`` | ``bottom`` >
         _Be aware that some pages do lazy loading and load more content once you scroll down._
         Bottom defines the current known bottom coordinate.
 
-        ``horizontal`` <str> defines where to scroll horizontally.
+        ``horizontal`` defines where to scroll horizontally.
         Works same as vertical but defines < ``left`` | ``right`` > as start and end.
 
-        ``behavior`` <str> defines whether the scroll happens directly or it scrolls smoothly.
-        < ``auto`` | ``smooth`` >
+        ``behavior`` defines whether the scroll happens directly or it scrolls smoothly.
         """
         scroll_size = self.library.get_scroll_size(selector)
         scroll_width = scroll_size["width"]
@@ -396,7 +425,7 @@ class Interaction(LibraryComponent):
             selector,
         )
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def scroll_by(
         self,
         selector: Optional[str] = None,
@@ -406,23 +435,22 @@ class Interaction(LibraryComponent):
     ):
         """Scrolls an element or the page relative from current position by the given values.
 
-        ``selector`` <str> Selector of the element. If the selector is ``${None}`` or ``${Empty}``
+        ``selector`` Selector of the element. If the selector is ``${None}`` or ``${Empty}``
         the page itself is scrolled.
         See the `Finding elements` section for details about the selectors.
 
-        ``vertical`` <str> defines how far and in which direction to scroll vertically.
+        ``vertical`` defines how far and in which direction to scroll vertically.
         It can be a positive or negative number. Positive scrolls down, like ``50``, negative scrolls up, like ``-50``.
         It can be a percentage value of the absolute scrollable size, like ``9.95%`` or negative like ``-10%``.
         It can be the string ``height`` to defining to scroll exactly one visible height down or up with ``-height``.
         _Be aware that some pages do lazy loading and load more content once you scroll down._
         The percentage of the current scrollable height is used and may change.
 
-        ``horizontal`` <str> defines where to scroll horizontally.
+        ``horizontal`` defines where to scroll horizontally.
         Works same as vertical but defines positive values for right and negative values for left.
         ``width`` defines to scroll exactly one visible range to the right.
 
-        ``behavior`` <str> defines whether the scroll happens directly or it scrolls smoothly.
-        < ``auto`` | ``smooth`` >
+        ``behavior`` defines whether the scroll happens directly or it scrolls smoothly.
         """
         scroll_size = self.library.get_scroll_size(selector)
         scroll_width = scroll_size["width"]
@@ -442,11 +470,11 @@ class Interaction(LibraryComponent):
             selector,
         )
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def check_checkbox(self, selector: str):
         """Checks the checkbox or selects radio button found by ``selector``.
 
-        ``selector`` <str> Selector of the checkbox. **Required**
+        ``selector`` Selector of the checkbox.
         See the `Finding elements` section for details about the selectors.
 
         Does nothing if the element is already checked/selected.
@@ -455,11 +483,11 @@ class Interaction(LibraryComponent):
             response = stub.CheckCheckbox(Request().ElementSelector(selector=selector))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def uncheck_checkbox(self, selector: str):
         """Unchecks the checkbox found by ``selector``.
 
-        ``selector`` <str> Selector of the checkbox. **Required**
+        ``selector`` Selector of the checkbox.
         See the `Finding elements` section for details about the selectors.
 
         Does nothing if the element is not checked/selected.
@@ -470,16 +498,16 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def select_options_by(self, selector: str, attribute: SelectAttribute, *values):
         """Selects options from select element found by ``selector``.
 
-        ``selector`` <str> Selector of the select tag. **Required**
+        ``selector`` Selector of the select tag.
         See the `Finding elements` section for details about the selectors.
 
         Matches based on the chosen attribute with list of ``values``.
         Possible attributes to match options by:
-        ``attribute`` < ``value`` | ``label `` | ``text`` | ``index`` >
+        ``attribute``
 
         If no values to select are passed will deselect options in element.
         """
@@ -500,11 +528,11 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def deselect_options(self, selector: str):
         """Deselects all options from select element found by ``selector``.
 
-        ``selector`` <str> Selector of the select tag. **Required**
+        ``selector`` Selector of the select tag.
         See the `Finding elements` section for details about the selectors.
         """
         with self.playwright.grpc_channel() as stub:
@@ -535,11 +563,11 @@ class Interaction(LibraryComponent):
             if log_response:
                 logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def upload_file(self, path: str):
         """Upload file from ``path`` into next file chooser dialog on page.
 
-        ``path`` <str> Path to file to be uploaded.
+        ``path`` Path to file to be uploaded.
 
         Example use:
 
@@ -553,14 +581,14 @@ class Interaction(LibraryComponent):
             response = stub.UploadFile(Request().FilePath(path=str(p)))
             logger.debug(response.log)
 
-    @keyword(tags=["PageContent"])
+    @keyword(tags=("PageContent",))
     def handle_future_dialogs(self, action: DialogAction, prompt_input: str = ""):
         """Handle next dialog on page with ``action``. Dialog can be any of alert,
         beforeunload, confirm or prompt.
 
-            ``action`` < ``acceppt`` | ``dismiss`` > How to handle the alert. **Required**
+            ``action`` How to handle the alert.
 
-            ``prompt_input`` <str> The value to enter into prompt. Only valid if
+            ``prompt_input`` The value to enter into prompt. Only valid if
             ``action`` equals accept. Defaults to empty string.
         """
 
@@ -572,7 +600,7 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def mouse_button(
         self,
         action: MouseButtonAction,
@@ -582,60 +610,45 @@ class Interaction(LibraryComponent):
         clickCount: int = 1,
         delay: int = 0,
     ):
-        """Click, hold a mouse button down or release it.
+        """Clicks, presses or releases a mouse button.
 
-        Moving the mouse between holding down and releasing it for example is possible with `Mouse Move`.
 
-        ``action`` < ``click`` | ``up`` | ``down`` > Determines if it is a mouseclick, holding down a key or releasing it.
+        ``action`` Determines if it is a mouseclick, holding down a key or releasing it.
 
-        ``x`` <int> and ``y`` <int> Coordinates for a click only. Defaults to None.
-        **Required** if action is a click.
+        ``x`` and ``y`` Coordinates to move before.
 
-        ``button`` < ``left``| ``right`` | ``middle`` > Defaults to ``left`` if invalid.
+        ``button`` Defaults to ``left``.
 
-        ``clickCount`` <int> Deterine how often shall be clicked. Defaults to 1.
+        ``clickCount`` Determine how often shall be clicked. Defaults to 1.
 
-        ``delay`` <int> Delay in ms between the mousedown and mouseup event. Can only be set if the action is click.
+        ``delay`` Delay in ms between the mousedown and mouseup event.
+        Can only be set if the action is click.
+
+        Moving the mouse between holding down and releasing it, is possible with `Mouse Move`.
         """
         with self.playwright.grpc_channel() as stub:
-            body: MouseOptionsDict = {}
-            if delay and action is not MouseButtonAction.click:
-                raise ValueError("Delay is only valid on 'click' action.")
-            if action == MouseButtonAction.click:
-                body = {}
-                if x and y:
-                    body["x"] = float(x)
-                    body["y"] = float(y)
-                else:
-                    raise ValueError(
-                        f"`Mouse Button    Click` requires that x and y are set! x: {x}, y: {y}"
-                    )
-                body["options"] = {
-                    "button": button.name,
-                    "clickCount": clickCount,
-                    "delay": delay,
-                }
+            if x and y:
+                self.mouse_move(x, y)
             else:
-                if x and y:
-                    self.mouse_move(x, y)
-                else:
-                    logger.info(
-                        f"No coordinates where set. Action will appear at current position. x: {x}, y {y}"
-                    )
-                body = {
-                    "options": {
-                        "button": button.name,
-                        "clickCount": clickCount,
-                        "delay": delay,
-                    }
-                }
-
+                logger.info(
+                    "No coordinates where set. Action appears at current position."
+                )
+            if action == MouseButtonAction.click:
+                for i in range(clickCount):
+                    self.mouse_button(MouseButtonAction.down, button=button)
+                    sleep(delay / 1000)
+                    self.mouse_button(MouseButtonAction.up, button=button)
+                return
+            else:
+                if delay:
+                    raise ValueError("Delay is only valid on 'click' action.")
+                body = {"options": {"button": button.name, "clickCount": clickCount}}
             response = stub.MouseButton(
                 Request().MouseButtonOptions(action=action.name, json=json.dumps(body))
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def drag_and_drop(self, selector_from: str, selector_to: str, steps: int = 1):
         """Executes a Drag&Drop operation from the element selected by ``selector_from``
         to the element selected by ``selector_to``.
@@ -648,11 +661,11 @@ class Interaction(LibraryComponent):
 
         Start- and end-point are defined by the center of the elements boundingbox.
 
-        ``selector_from``: <float> identifies the element, which center is the start-point. **Required**
+        ``selector_from`` identifies the element, which center is the start-point.
 
-        ``selector_to``: <float> identifies the element, which center is the end-point. **Required**
+        ``selector_to`` identifies the element, which center is the end-point.
 
-        ``steps``: <int> defines how many intermediate mouse move events are sent.
+        ``steps`` defines how many intermediate mouse move events are sent.
         """
         from_bbox = self.library.get_boundingbox(selector_from)
         from_xy = self._center_of_boundingbox(from_bbox)
@@ -662,7 +675,7 @@ class Interaction(LibraryComponent):
         self.mouse_move(**to_xy, steps=steps)
         self.mouse_button(MouseButtonAction.up)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def drag_and_drop_by_coordinates(
         self, from_x: float, from_y: float, to_x: float, to_y: float, steps: int = 1
     ):
@@ -676,11 +689,11 @@ class Interaction(LibraryComponent):
         Start- and end-point are defined by ``x`` and ``y`` coordinates relative to
         the top left corner of the pages viewport.
 
-        ``from_x`` & ``from_y``: <float> identify the the start-point. **Required**
+        ``from_x`` & ``from_y`` identify the the start-point.
 
-        ``to_x`` & ``to_y``: <float> identify the the end-point. **Required**
+        ``to_x`` & ``to_y`` identify the the end-point.
 
-        ``steps``: <int> defines how many intermediate mouse move events are sent.
+        ``steps`` defines how many intermediate mouse move events are sent.
         """
         self.mouse_button(MouseButtonAction.down, x=from_x, y=from_y)
         self.mouse_move(x=to_x, y=to_y, steps=steps)
@@ -693,15 +706,44 @@ class Interaction(LibraryComponent):
         center["y"] = boundingbox["y"] + (boundingbox["height"] / 2)
         return center
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
+    def mouse_move_relative_to(
+        self, selector: str, x: float = 0.0, y: float = 0.0, steps: int = 1
+    ):
+        """Moves the mouse cursor relative to the selected element.
+
+        ``x`` ``y`` are relative coordinates to the center of the elements bounding box.
+
+        ``steps`` Number of intermediate steps for the mouse event.
+        This is sometime needed for websites to recognize the movement.
+        """
+        with self.playwright.grpc_channel() as stub:
+            bbox = self.library.get_boundingbox(selector)
+            center = self._center_of_boundingbox(bbox)
+            body: MouseOptionsDict = {
+                "x": center["x"] + x,
+                "y": center["y"] + y,
+                "options": {"steps": steps},
+            }
+            logger.info(
+                f"Moving mouse relative to element center by x: {x}, y: {y} coordinates."
+            )
+            logger.debug(f"Element Center is: {center}")
+            logger.debug(
+                f"Mouse Position is: {{'x': {center['x'] + x}, 'y': {center['y'] + y}}}"
+            )
+            response = stub.MouseMove(Request().Json(body=json.dumps(body)))
+            logger.debug(response.log)
+
+    @keyword(tags=("Setter", "PageContent"))
     def mouse_move(self, x: float, y: float, steps: int = 1):
         """Instead of selectors command mouse with coordinates.
         The Click commands will leave the virtual mouse on the specified coordinates.
 
-        ``x`` <float> ``y`` <float> are absolute coordinates starting at the top left
+        ``x`` ``y`` are absolute coordinates starting at the top left
         of the page.
 
-        ``steps`` <int> Number of intermediate steps for the mouse event.
+        ``steps`` Number of intermediate steps for the mouse event.
         """
         with self.playwright.grpc_channel() as stub:
             body: MouseOptionsDict = {"x": x, "y": y, "options": {"steps": steps}}
@@ -709,15 +751,15 @@ class Interaction(LibraryComponent):
             response = stub.MouseMove(Request().Json(body=json.dumps(body)))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def keyboard_key(self, action: KeyAction, key: str):
         """Press a keyboard key on the virtual keyboard or set a key up or down.
 
-        ``action`` < ``up`` | ``down`` | ``press`` > Determine whether the key should be released,
+        ``action`` Determine whether the key should be released,
         hold or pressed. ``down`` or ``up`` are useful for combinations i.e. with Shift.
-        **Required**
 
-        ``key`` <str> The key to be pressed. An example of valid keys are:
+
+        ``key`` The key to be pressed. An example of valid keys are:
 
         ``F1`` - ``F12``, ``Digit0`` - ``Digit9``, ``KeyA``- ``KeyZ``, ``Backquote``, ``Minus``,
         ``Equal``, ``Backslash``, ``Backspace``, ``Tab``, ``Delete``, ``Escape``, ``ArrowDown``,
@@ -743,17 +785,17 @@ class Interaction(LibraryComponent):
             )
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
+    @keyword(tags=("Setter", "PageContent"))
     def keyboard_input(self, action: KeyboardInputAction, input: str, delay=0):
         """Input text into page with virtual keyboard.
 
-        ``action`` < ``insertText`` | ``type`` > **Required**
+        ``action``
 
             - ``insertText`` Dispatches only input event, does not emit the keydown, keyup or keypress events.
 
             - ``type`` Sends a keydown, keypress/input, and keyup event for each character in the text.
 
-        ``input`` <str> The inputstring to be typed. No special keys possible. **Required**
+        ``input`` The inputstring to be typed. No special keys possible.
 
         Note: To press a special key, like Control or ArrowDown, use keyboard.press.
         Modifier keys DO NOT effect these methods. For testing modifier effects use single key
